@@ -15,9 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-event.c,v 1.10 2004/01/15 18:08:22 chpe Exp $
+ *  $Id: ephy-embed-event.c,v 1.12 2004/03/17 09:02:31 marco Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ephy-embed-event.h"
 
 #include <glib/ghash.h>
@@ -41,7 +45,7 @@ ephy_embed_event_get_type (void)
 	{
 		static const GTypeInfo our_info =
 		{
-			sizeof (EphyEmbedEventIFace),
+			sizeof (EphyEmbedEventIface),
 			ephy_embed_event_base_init,
 			NULL,
 		};
@@ -66,21 +70,21 @@ ephy_embed_event_base_init (gpointer g_class)
 EphyEmbedEventType
 ephy_embed_event_get_event_type (EphyEmbedEvent *event)
 {
-	EphyEmbedEventIFace *iface = EPHY_EMBED_EVENT_GET_IFACE (event);
+	EphyEmbedEventIface *iface = EPHY_EMBED_EVENT_GET_IFACE (event);
 	return iface->get_type (event);
 }
 
 EmbedEventContext
 ephy_embed_event_get_context (EphyEmbedEvent *event)
 {
-	EphyEmbedEventIFace *iface = EPHY_EMBED_EVENT_GET_IFACE (event);
+	EphyEmbedEventIface *iface = EPHY_EMBED_EVENT_GET_IFACE (event);
 	return iface->get_context (event);
 }
 
 guint
 ephy_embed_event_get_modifier (EphyEmbedEvent *event)
 {
-	EphyEmbedEventIFace *iface = EPHY_EMBED_EVENT_GET_IFACE (event);
+	EphyEmbedEventIface *iface = EPHY_EMBED_EVENT_GET_IFACE (event);
 	return iface->get_modifier (event);
 }
 
@@ -88,7 +92,7 @@ void
 ephy_embed_event_get_coords (EphyEmbedEvent *event,
 			     guint *x, guint *y)
 {
-	EphyEmbedEventIFace *iface = EPHY_EMBED_EVENT_GET_IFACE (event);
+	EphyEmbedEventIface *iface = EPHY_EMBED_EVENT_GET_IFACE (event);
 	iface->get_coordinates (event, x, y);
 }
 
@@ -97,7 +101,7 @@ ephy_embed_event_get_property	(EphyEmbedEvent *event,
 				 const char *name,
 				 const GValue **value)
 {
-	EphyEmbedEventIFace *iface = EPHY_EMBED_EVENT_GET_IFACE (event);
+	EphyEmbedEventIface *iface = EPHY_EMBED_EVENT_GET_IFACE (event);
 	iface->get_property (event, name, value);
 }
 
@@ -105,13 +109,13 @@ gboolean
 ephy_embed_event_has_property	(EphyEmbedEvent *event,
 				 const char *name)
 {
-	EphyEmbedEventIFace *iface = EPHY_EMBED_EVENT_GET_IFACE (event);
+	EphyEmbedEventIface *iface = EPHY_EMBED_EVENT_GET_IFACE (event);
 	return iface->has_property (event, name);
 }
 
 gpointer
 ephy_embed_event_get_dom_event (EphyEmbedEvent *event)
 {
-	EphyEmbedEventIFace *iface = EPHY_EMBED_EVENT_GET_IFACE (event);
+	EphyEmbedEventIface *iface = EPHY_EMBED_EVENT_GET_IFACE (event);
 	return iface->get_dom_event (event);
 }
