@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-file-helpers.h,v 1.9 2004/02/21 19:58:05 chpe Exp $
+ *  $Id: ephy-file-helpers.h,v 1.10 2004/07/22 09:17:09 marco Exp $
  */
 
 #ifndef EPHY_FILE_HELPERS_H
@@ -40,7 +40,7 @@ const char *ephy_file_tmp_dir	 	 (void);
 char       *ephy_file_tmp_filename	 (const char *base,
 					  const char *extension);
 
-void	    ephy_ensure_dir_exists       (const char *dir);
+gboolean    ephy_ensure_dir_exists       (const char *dir);
 
 GSList     *ephy_file_find               (const char *path,
 				          const char *fname,
