@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks-import.c,v 1.33 2004/06/26 12:15:21 marco Exp $
+ *  $Id: ephy-bookmarks-import.c,v 1.36 2004/08/09 15:19:39 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -71,6 +71,7 @@ ephy_bookmarks_import (EphyBookmarks *bookmarks,
 {
 	GnomeVFSURI *uri;
 	const char *type;
+	gboolean success = FALSE;
 
 	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_BOOKMARK_EDITING)) return FALSE;
 
@@ -79,35 +80,41 @@ ephy_bookmarks_import (EphyBookmarks *bookmarks,
 
 	LOG ("Importing bookmarks of type %s", type)
 
-	if (type == NULL) return FALSE;
+	if (type == NULL)
+	{
+		gnome_vfs_uri_unref (uri);
+		 return FALSE;
+	}
 
 	if (strcmp (type, "application/x-mozilla-bookmarks") == 0)
 	{
-		return ephy_bookmarks_import_mozilla (bookmarks, filename);
+		success = ephy_bookmarks_import_mozilla (bookmarks, filename);
 	}
 	else if (strcmp (type, "application/x-xbel") == 0)
 	{
-		return ephy_bookmarks_import_xbel (bookmarks, filename);
+		success = ephy_bookmarks_import_xbel (bookmarks, filename);
 	}
-	else if (strcmp (type, "text/rdf") == 0)
+	else if (strcmp (type, "application/rdf+xml") == 0 ||
+		 strcmp (type, "text/rdf") == 0)
 	{
-		return ephy_bookmarks_import_rdf (bookmarks, filename);
+		success = ephy_bookmarks_import_rdf (bookmarks, filename);
 	}
 	else if (strstr (filename, MOZILLA_BOOKMARKS_DIR) != NULL ||
                  strstr (filename, FIREBIRD_BOOKMARKS_DIR) != NULL ||
 		 strstr (filename, FIREFOX_BOOKMARKS_DIR) != NULL)
 	{
-		return ephy_bookmarks_import_mozilla (bookmarks, filename);
+		success = ephy_bookmarks_import_mozilla (bookmarks, filename);
 	}
 	else if (strstr (filename, GALEON_BOOKMARKS_DIR) != NULL ||
 		 strstr (filename, KDE_BOOKMARKS_DIR) != NULL)
 	{
-		return ephy_bookmarks_import_xbel (bookmarks, filename);
+		success = ephy_bookmarks_import_xbel (bookmarks, filename);
 	}
+	/* else FIXME: put up some UI to warn user about unrecognised format? */
 
 	gnome_vfs_uri_unref (uri);
 
-	return FALSE;
+	return success;
 }
 
 /* XBEL import */
@@ -145,7 +152,7 @@ xbel_parse_bookmark (EphyBookmarks *eb, xmlTextReaderPtr reader, EphyNode **ret_
 
 		type = xmlTextReaderNodeType (reader);
 
-		if (xmlStrEqual (tag, "#text"))
+		if (xmlStrEqual (tag, (xmlChar *) "#text"))
 		{
 			if (state == STATE_TITLE && title == NULL)
 			{
@@ -161,11 +168,11 @@ xbel_parse_bookmark (EphyBookmarks *eb, xmlTextReaderPtr reader, EphyNode **ret_
 				/* eat it */
 			}
 		}
-		else if (xmlStrEqual (tag, "bookmark"))
+		else if (xmlStrEqual (tag, (xmlChar *) "bookmark"))
 		{
 			if (type == XML_READER_TYPE_ELEMENT && state == STATE_BOOKMARK && address == NULL)
 			{
-				address = xmlTextReaderGetAttribute (reader, "href");
+				address = xmlTextReaderGetAttribute (reader, (xmlChar *) "href");
 			}
 			else if (type == XML_READER_TYPE_END_ELEMENT && state == STATE_BOOKMARK)
 			{
@@ -174,7 +181,7 @@ xbel_parse_bookmark (EphyBookmarks *eb, xmlTextReaderPtr reader, EphyNode **ret_
 				break;
 			}
 		}
-		else if (xmlStrEqual (tag, "title"))
+		else if (xmlStrEqual (tag, (xmlChar *) "title"))
 		{
 			if (type == XML_READER_TYPE_ELEMENT && state == STATE_BOOKMARK && title == NULL)
 			{
@@ -185,7 +192,7 @@ xbel_parse_bookmark (EphyBookmarks *eb, xmlTextReaderPtr reader, EphyNode **ret_
 				state = STATE_BOOKMARK;
 			}
 		}
-		else if (xmlStrEqual (tag, "desc"))
+		else if (xmlStrEqual (tag, (xmlChar *) "desc"))
 		{
 			if (type == XML_READER_TYPE_ELEMENT && state == STATE_BOOKMARK)
 			{
@@ -196,7 +203,7 @@ xbel_parse_bookmark (EphyBookmarks *eb, xmlTextReaderPtr reader, EphyNode **ret_
 				state = STATE_BOOKMARK;
 			}
 		}
-		else if (xmlStrEqual (tag, "info"))
+		else if (xmlStrEqual (tag, (xmlChar *) "info"))
 		{
 			if (type == XML_READER_TYPE_ELEMENT && state == STATE_BOOKMARK)
 			{
@@ -207,7 +214,7 @@ xbel_parse_bookmark (EphyBookmarks *eb, xmlTextReaderPtr reader, EphyNode **ret_
 				state = STATE_BOOKMARK;
 			}
 		}
-		else if (xmlStrEqual (tag, "metadata"))
+		else if (xmlStrEqual (tag, (xmlChar *) "metadata"))
 		{
 			if (type == XML_READER_TYPE_ELEMENT && state == STATE_INFO)
 			{
@@ -218,7 +225,7 @@ xbel_parse_bookmark (EphyBookmarks *eb, xmlTextReaderPtr reader, EphyNode **ret_
 				state = STATE_INFO;
 			}
 		}
-		else if (xmlStrEqual (tag, "smarturl"))
+		else if (xmlStrEqual (tag, (xmlChar *) "smarturl"))
 		{
 			if (type == XML_READER_TYPE_ELEMENT && state == STATE_METADATA)
 			{
@@ -241,14 +248,14 @@ xbel_parse_bookmark (EphyBookmarks *eb, xmlTextReaderPtr reader, EphyNode **ret_
 
 	if (title == NULL)
 	{
-		title = xmlStrdup (_("Untitled"));
+		title = xmlStrdup ((xmlChar *) _("Untitled"));
 	}
 
-	node = bookmark_add (eb, title, address);
+	node = bookmark_add (eb, (const char *) title, (const char *) address);
 	if (node == NULL)
 	{
 		/* probably a duplicate */
-		node = ephy_bookmarks_find_bookmark (eb, address);		
+		node = ephy_bookmarks_find_bookmark (eb, (const char *) address);
 	}
 
 	xmlFree (title);
@@ -280,13 +287,13 @@ xbel_parse_folder (EphyBookmarks *eb, xmlTextReaderPtr reader, char *parent_fold
 		{
 			/* shouldn't happen but does anyway :) */
 		}
-		else if (xmlStrEqual (tag, "#text"))
+		else if (xmlStrEqual (tag, (xmlChar *) "#text"))
 		{
 			if (state == STATE_TITLE && folder == NULL)
 			{
 				char *title;
 
-				title = xmlTextReaderValue (reader);
+				title = (char *) xmlTextReaderValue (reader);
 
 				if (!parent_folder)
 				{
@@ -305,7 +312,7 @@ xbel_parse_folder (EphyBookmarks *eb, xmlTextReaderPtr reader, char *parent_fold
 				/* eat it */
 			}
 		}
-		else if (xmlStrEqual (tag, "bookmark") && type == 1 && state == STATE_FOLDER)
+		else if (xmlStrEqual (tag, (xmlChar *) "bookmark") && type == 1 && state == STATE_FOLDER)
 		{
 			EphyNode *node = NULL, *keyword;
 
@@ -325,7 +332,7 @@ xbel_parse_folder (EphyBookmarks *eb, xmlTextReaderPtr reader, char *parent_fold
 
 			if (ret != 1) break;
 		}
-		else if ((xmlStrEqual (tag, "folder"))
+		else if ((xmlStrEqual (tag, (xmlChar *) "folder"))
 			&& state == STATE_FOLDER)
 		{
 			if (type == XML_READER_TYPE_ELEMENT)
@@ -341,7 +348,7 @@ xbel_parse_folder (EphyBookmarks *eb, xmlTextReaderPtr reader, char *parent_fold
 				break;
 			}
 		}
-		else if (xmlStrEqual (tag, "title"))
+		else if (xmlStrEqual (tag, (xmlChar *) "title"))
 		{
 			if (type == XML_READER_TYPE_ELEMENT && state == STATE_FOLDER)
 			{
@@ -352,7 +359,7 @@ xbel_parse_folder (EphyBookmarks *eb, xmlTextReaderPtr reader, char *parent_fold
 				state = STATE_FOLDER;
 			}
 		}
-		else if (xmlStrEqual (tag, "info"))
+		else if (xmlStrEqual (tag, (xmlChar *) "info"))
 		{
 			if (type == XML_READER_TYPE_ELEMENT && state == STATE_FOLDER)
 			{
@@ -363,7 +370,7 @@ xbel_parse_folder (EphyBookmarks *eb, xmlTextReaderPtr reader, char *parent_fold
 				state = STATE_FOLDER;
 			}
 		}
-		else if (xmlStrEqual (tag, "desc"))
+		else if (xmlStrEqual (tag, (xmlChar *) "desc"))
 		{
 			if (type == XML_READER_TYPE_ELEMENT && state == STATE_FOLDER)
 			{
@@ -408,7 +415,7 @@ xbel_parse_xbel (EphyBookmarks *eb, xmlTextReaderPtr reader)
 		{
 			/* shouldn't happen but does anyway :( */
 		}
-		else if (xmlStrEqual (tag, "bookmark") && type == XML_READER_TYPE_ELEMENT
+		else if (xmlStrEqual (tag, (xmlChar *) "bookmark") && type == XML_READER_TYPE_ELEMENT
 			 && state == STATE_FOLDER)
 		{
 			EphyNode *node = NULL;
@@ -418,7 +425,7 @@ xbel_parse_xbel (EphyBookmarks *eb, xmlTextReaderPtr reader)
 
 			if (ret != 1) break;
 		}
-		else if (xmlStrEqual (tag, "folder") && type == XML_READER_TYPE_ELEMENT
+		else if (xmlStrEqual (tag, (xmlChar *) "folder") && type == XML_READER_TYPE_ELEMENT
 			 && state == STATE_XBEL)
 		{
 			/* this will eat the </folder> too */
@@ -426,17 +433,17 @@ xbel_parse_xbel (EphyBookmarks *eb, xmlTextReaderPtr reader)
 
 			if (ret != 1) break;
 		}
-		else if ((xmlStrEqual (tag, "xbel")) && type == XML_READER_TYPE_ELEMENT
+		else if ((xmlStrEqual (tag, (xmlChar *) "xbel")) && type == XML_READER_TYPE_ELEMENT
 			 && state == STATE_START)
 		{
 			state = STATE_XBEL;
 		}
-		else if ((xmlStrEqual (tag, "xbel")) && type == XML_READER_TYPE_END_ELEMENT
+		else if ((xmlStrEqual (tag, (xmlChar *) "xbel")) && type == XML_READER_TYPE_END_ELEMENT
 			 && state == STATE_XBEL)
 		{
 			state = STATE_STOP;
 		}
-		else if (xmlStrEqual (tag, "title"))
+		else if (xmlStrEqual (tag, (xmlChar *) "title"))
 		{
 			if (type == XML_READER_TYPE_ELEMENT && state == STATE_XBEL)
 			{
@@ -447,7 +454,7 @@ xbel_parse_xbel (EphyBookmarks *eb, xmlTextReaderPtr reader)
 				state = STATE_XBEL;
 			}
 		}
-		else if (xmlStrEqual (tag, "info"))
+		else if (xmlStrEqual (tag, (xmlChar *) "info"))
 		{
 			if (type == XML_READER_TYPE_ELEMENT && state == STATE_XBEL)
 			{
@@ -458,7 +465,7 @@ xbel_parse_xbel (EphyBookmarks *eb, xmlTextReaderPtr reader)
 				state = STATE_XBEL;
 			}
 		}
-		else if (xmlStrEqual (tag, "desc"))
+		else if (xmlStrEqual (tag, (xmlChar *) "desc"))
 		{
 			if (type == XML_READER_TYPE_ELEMENT && state == STATE_XBEL)
 			{
@@ -682,7 +689,6 @@ ephy_bookmarks_import_mozilla (EphyBookmarks *bookmarks,
 	FILE *bf;  /* bookmark file */
 	GString *name, *url;
 	char *parsedname, *topic;
-	EphyNode *keyword;
 	GList *folders = NULL;
 
 	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_BOOKMARK_EDITING)) return FALSE;
@@ -725,20 +731,25 @@ ephy_bookmarks_import_mozilla (EphyBookmarks *bookmarks,
 				node = ephy_bookmarks_find_bookmark (bookmarks, url->str);
 			}
 
-			topic = folders_list_to_topic_name (folders);
-			keyword = ephy_bookmarks_find_keyword (bookmarks, topic, FALSE);
-			
-			if (keyword == NULL)
-			{
-				keyword = ephy_bookmarks_add_keyword (bookmarks, topic);
-			}
+			g_return_val_if_fail (node != NULL, FALSE);
 
-			if (node != NULL && keyword != NULL)
+			if (folders != NULL)
 			{
+				EphyNode *keyword;
+
+				topic = folders_list_to_topic_name (folders);
+				g_return_val_if_fail (topic != NULL, FALSE);
+
+				keyword = ephy_bookmarks_find_keyword (bookmarks, topic, FALSE);
+				if (keyword == NULL)
+				{
+					keyword = ephy_bookmarks_add_keyword (bookmarks, topic);
+				}
+				g_free (topic);
+
 				ephy_bookmarks_set_keyword (bookmarks, keyword, node);
 			}
 
-			g_free (topic);
 			g_free (parsedname);
 
 			break;
@@ -795,13 +806,13 @@ parse_rdf_subjects (xmlNodePtr node,
 
 	while (child != NULL)
 	{
-		if (xmlStrEqual (child->name, "Bag"))
+		if (xmlStrEqual (child->name, (xmlChar *) "Bag"))
 		{
 			child = child->children;
 
 			while (child != NULL)
 			{
-				if (xmlStrEqual (child->name, "li"))
+				if (xmlStrEqual (child->name, (xmlChar *) "li"))
 				{
 					subject = xmlNodeGetContent (child);
 					*subjects = g_list_append (*subjects, subject);
@@ -838,26 +849,26 @@ parse_rdf_item (EphyBookmarks *bookmarks,
 	child = node->children;
 
 #ifdef OLD_RDF_TEMPORARY_HACK
-	link = xmlGetProp (node, "about");
+	link = xmlGetProp (node, (xmlChar *) "about");
 #endif
 
 	while (child != NULL)
 	{
-		if (xmlStrEqual (child->name, "title"))
+		if (xmlStrEqual (child->name, (xmlChar *) "title"))
 		{
 			title = xmlNodeGetContent (child);
 		}
 #ifndef OLD_RDF_TEMPORARY_HACK
-		else if (xmlStrEqual (child->name, "link"))
+		else if (xmlStrEqual (child->name, (xmlChar *) "link"))
 		{
 			link = xmlNodeGetContent (child);
 		}
 #endif
-		else if (xmlStrEqual (child->name, "subject"))
+		else if (xmlStrEqual (child->name, (xmlChar *) "subject"))
 		{
 			parse_rdf_subjects (child, &subjects);
 		}
-		else if (xmlStrEqual (child->name, "smartlink"))
+		else if (xmlStrEqual (child->name, (xmlChar *) "smartlink"))
 		{
 			if (link) xmlFree (link);
 			link = xmlNodeGetContent (child);
@@ -866,7 +877,7 @@ parse_rdf_item (EphyBookmarks *bookmarks,
 		child = child->next;
 	}
 
-	bmk = bookmark_add (bookmarks, title, link);
+	bmk = bookmark_add (bookmarks, (char *) title, (char *) link);
 	if (bmk)
 	{
 		l = subjects;
@@ -926,7 +937,7 @@ ephy_bookmarks_import_rdf (EphyBookmarks *bookmarks,
 
 	while (child != NULL)
 	{
-		if (xmlStrEqual (child->name, "item"))
+		if (xmlStrEqual (child->name, (xmlChar *) "item"))
 		{
 			parse_rdf_item (bookmarks, child);
 		}
