@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c,v 1.128 2004/06/26 18:28:44 chpe Exp $
+ *  $Id: window-commands.c,v 1.131 2004/08/04 13:52:46 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -286,7 +286,7 @@ window_cmd_file_new_window (GtkAction *action,
 	tab = ephy_window_get_active_tab (window);
 	g_return_if_fail (tab != NULL);
 
-	ephy_shell_new_tab (ephy_shell, NULL, tab, NULL,
+	ephy_shell_new_tab (ephy_shell, window, tab, NULL,
 			    EPHY_NEW_TAB_NEW_PAGE |
 			    EPHY_NEW_TAB_IN_NEW_WINDOW);
 }
@@ -451,6 +451,12 @@ window_cmd_file_close_window (GtkAction *action,
 {
 	EphyTab *tab;
 
+	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_QUIT) &&
+	    gtk_notebook_get_n_pages (GTK_NOTEBOOK (ephy_window_get_notebook (window))) == 1)
+	{
+		return;
+	}
+
 	tab = ephy_window_get_active_tab (window);
 	g_return_if_fail (tab != NULL);
 
@@ -722,6 +728,11 @@ editor_can_open_uri (char *address)
 		gnome_vfs_uri_unref (uri);
 	}
 
+	if (app)
+	{
+		gnome_vfs_mime_application_free (app);
+	}
+
 	return result;
 }
 
@@ -783,6 +794,8 @@ window_cmd_view_page_source (GtkAction *action,
 	{
 		save_temp_source (embed);
 	}
+
+	g_free (address);
 }
 
 void
